<div align="center">

[//]: # (<img  src="https://cdn.liteyuki.icu/static/svg/lylogo-full.svg" style="align-content: center; width: 50%; margin-top:10%;" alt="a">)
[![][banner]][lightyuki-link]
<h2><a href="https://bot.liteyuki.icu"> <span style="color: #a2d8f4">轻雪</span> <span style="color: #d0e9ff">6</span></a></h2>
<h4> <span style="color: #a2d8f4">✨ 轻量，高效，易于扩展✨</span></h4>

[![][OneBot]][onebot-link]
[![][NoneBot2]][nonebot-link]
[![][Liteyuki6.0]][lightyuki-link]
[![][Python3.10+]][python-link]
[![][Usage]][usage-link]

- 基于[Nonebot2](https://github.com/nonebot/nonebot2)，有良好的生态支持
- 开箱即用，无需复杂配置
- 集成包管理器，支持一键安装插件
- 支持OneBot标准通信但不限于此
- 自定义主题支持，满足审美需求
- 国际化支持，支持多种语言
- 高性能，500插件2s内启动

<h3>👇更多内容请访问👇</h3>
<h2><a href="https://bot.liteyuki.icu">轻雪机器人主页</a></h2>
</div>

### 感谢
- [NoneBot2](https://nonebot.dev)提供的框架支持
- [nonebot-plugin-htmlrender](https://github.com/kexue-z/nonebot-plugin-htmlrender)提供的渲染功能
- [nonebot-plugin-alconna](https://github.com/ArcletProject/nonebot-plugin-alconna)提供的命令解析功能


[OneBot]: https://img.shields.io/badge/OneBot-11/12-blue?style=for-the-badge

[NoneBot2]: https://img.shields.io/badge/Nonebot-2-red?style=for-the-badge

[Liteyuki6.0]: https://img.shields.io/badge/Liteyuki-6.0-blue?style=for-the-badge

[Python3.10+]: https://img.shields.io/badge/Python-3.10+-blue?style=for-the-badge

[Usage]: https://img.shields.io/badge/文档-页面-blue?style=for-the-badge

[onebot-link]:https://onebot.dev/

[nonebot-link]:https://nonebot.dev/

[lightyuki-link]:/

[python-link]:https://www.python.org/

[usage-link]:https://bot.liteyuki.icu/

[banner]: https://socialify.git.ci/LiteyukiStudio/LiteyukiBot/image?description=1&forks=1&issues=1&Plus&pulls=1&stargazers=1&theme=Auto&logo=https%3a%2f%2fcdn.liteyuki.icu%2fstatic%2fsvg%2flylogo-full.svg
